/** 
 *******************************************************************************
 * @file    tmpm375_trmosc.h
 * @brief   the application functions of TRMOSC demo for the TOSHIBA
 *          'TMPM375' Device Series 
 * @version 0.0.0.1
 * @date    2014/09/29
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM375_TRMOSC_H
#define __TMPM375_TRMOSC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "TMPM375.h"
#include "tx03_common.h"

/** @addtogroup TX03_Periph_Driver
  * @{
  */

/** @addtogroup TRMOSC
  * @{
  */

/** @addtogroup TRMOSC_Exported_types
  * @{
  */

/**
  * @brief TRMOSC Control Structure definition
  */

    typedef struct {
        uint32_t TrimmingControl;       /*!< Value to <TRIMEN> */
        uint32_t CoarseTrimmingValue;   /*!< Value to <TRIMSETC> */
        uint32_t FineTrimmingValue;     /*!< Value to <TRIMSETF> */
    } TRMOSC_ControlTypeDef;

#define  TRMOSC_CONTROL_ENABLE		(0x00000001UL)  /*!< Trimming Control enable */
#define  TRMOSC_CONTROL_DISABLE		(0x00000000UL)  /*!< Trimming Control disable  */

/** @} */
/* End of group TRMOSC_Exported_types */

/** @defgroup TRMOSC_Exported_FunctionPrototypes
  * @{
  */
    void SetTrmOsc(TRMOSC_ControlTypeDef * ControlStruct);
    uint32_t GetTrimmingControlValue(void);
    uint32_t GetInitCoarseTrimValue(void);
    uint32_t GetInitFineTrimValue(void);
    uint32_t GetCoarseTrimValueSet(void);
    uint32_t GetFineTrimValueSet(void);


/** @} */
/* End of group TRMOSC_Exported_FunctionPrototypes */

/** @} */
/* End of group TRMOSC */

/** @} */
/* End of group TX03_Periph_Driver */

#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM375_TRMOSC_H */
