/** 
 *******************************************************************************
 * @file    tmpm375_trmosc.c
 * @brief   the application functions of TRMOSC demo for the TOSHIBA
 *          'TMPM375' Device Series 
 * @version 0.0.0.1
 * @date    2014/09/29
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm375_trmosc.h"

/* Private variable -----------------------------------------------*/
#define  REGSTERENABLE				(0x000000C1UL)  /* Writing register control enable */
#define  REGSTERDISABLE				(0x00000000UL)  /* Writing register control disable */
#define  TRMOSCEN_MASK				(0x00000001UL)  /*  */
#define  TRIMCOARSE_MASK			(0x00003F00UL)  /*  */
#define  TRIMFINE_MASK				(0x0000000FUL)  /*  */

/* Private function prototypes -----------------------------------------------*/


/**
  * @brief  Set TRMOSC register
  * @param  TRMOSC Control Structure
  * @retval None
  * @register The used registers:
  *   TRMOSCPRO<PROTECT[7:0]> 
  *   TRMOSCEN<TRIMEN>
  *   TRMOSCINIT<TRIMINITC[13:8]>  
  *   TRMOSCINIT<TRIMINITF[3:0]>
  *   TRMOSCSET<TRIMINITC[13:8]>  
  *   TRMOSCSET<TRIMINITF[3:0]>
  */
void SetTrmOsc(TRMOSC_ControlTypeDef * ControlStruct)
{
    uint32_t tmp = 0;

    TSB_TRMOSC->PRO = REGSTERENABLE;
    TSB_TRMOSC->EN = ControlStruct->TrimmingControl;
    tmp = (ControlStruct->CoarseTrimmingValue << 8) & TRIMCOARSE_MASK;
    tmp |= ControlStruct->FineTrimmingValue & TRIMFINE_MASK;
    TSB_TRMOSC->SET = tmp;
    TSB_TRMOSC->PRO = REGSTERDISABLE;
}

/**
  * @brief  Get Trimming Control Value
  * @param  None
  * @retval Trimming Control value
  * @register The used registers: 
  *   TRMOSCEN<TRIMEN>
  */
uint32_t GetTrimmingControlValue(void)
{
    return (TSB_TRMOSC->EN & TRMOSCEN_MASK);
}

/**
  * @brief  Get Initial Coarse Trimming Value
  * @param  None
  * @retval Initial Coarse Trimming value
  * @register The used registers:
  *   TRMOSCINIT<TRIMINITC[13:8]>  
  */
uint32_t GetInitCoarseTrimValue(void)
{
    return ((TSB_TRMOSC->INIT & TRIMCOARSE_MASK) >> 8);
}

/**
  * @brief  Get initial Fine Trimming Value
  * @param  None
  * @retval Initial Fine Trimming value
  * @register The used registers:  
  *   TRMOSCINIT<TRIMINITF[3:0]>  
  */
uint32_t GetInitFineTrimValue(void)
{
    return (TSB_TRMOSC->INIT & TRIMFINE_MASK);
}

/**
  * @brief  Get Coarse Trimming value setting
  * @param  None
  * @retval Coarse Trimming value setting
  * @register The used registers:
  *   TRMOSCSET<TRIMINITC[13:8]>  
  */
uint32_t GetCoarseTrimValueSet(void)
{
    return ((TSB_TRMOSC->SET & TRIMCOARSE_MASK) >> 8);
}


/**
  * @brief  Get Fine Trimming value setting
  * @param  None
  * @retval Fine Trimming value setting
  * @register The used registers:  
  *   TRMOSCSET<TRIMINITF[3:0]>  
  */
uint32_t GetFineTrimValueSet(void)
{
    return (TSB_TRMOSC->SET & TRIMFINE_MASK);
}
