/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of DNF demo for the TOSHIBA
 *          'TMPM375' Device Series 
 * @version V0.100
 * @date    2014/10/08
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"
/* Private define ------------------------------------------------------------*/
#define  CORRECT_PULSE
/* #define  NOISE_PULSE */ 
/* Global variables ----------------------------------------------------------*/
volatile uint32_t Flag = 0U;
#if defined CORRECT_PULSE
    uint32_t RG0Value = 0x00000007U;
    uint32_t RG1Value = 0x0000000EU;
#elif defined NOISE_PULSE
    uint32_t RG0Value = 0x00000009U;
    uint32_t RG1Value = 0x00000012U;
#endif
/* Private functions ---------------------------------------------------------*/
/* Main function */
int main(void)
{
    /* Configure UART */
    hardware_init(UART_RETARGET);
  
    /* Configure 16-bit PPG */
    TMRB7_Config();
    /* Start PPG count operation */
    TMRB_SetRunState(TSB_TB7, TMRB_RUN);

    /* Configure GPIO to INT7 */
    GPIO_SetInput(GPIO_PE, GPIO_BIT_2);
    GPIO_EnableFuncReg(GPIO_PE, GPIO_FUNC_REG_4, GPIO_BIT_2);
 
    /* fsys/4 clock output, 10 MHz */
    DNF_SetFilterClk(DNF_FILTER_CLK_FSYS_4);
    /* Enable INT7 noise filter circuit */
    DNF_SetInt7Filter(ENABLE);

    /* Set interrupt for DNF */
    __disable_irq();
    NVIC_ClearPendingIRQ(INT7_IRQn);
    NVIC_EnableIRQ(INT7_IRQn);
    __enable_irq();

    while(1U) {
#if defined CORRECT_PULSE
        if (Flag == 1U) {
            common_uart_disp("DNF processed with error !\r\n");
        } else {
            common_uart_disp("Correct pulse is detected !\r\n");
        }
#elif defined NOISE_PULSE
        if (Flag == 1U) {
            common_uart_disp("Noise pulse is detected !\r\n");
        } else {
            common_uart_disp("DNF processed with error !\r\n");
        }
#endif
    } 
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif

/*********************************** END OF FILE ******************************/
