/** 
 *******************************************************************************
 * @file    tmrb.c
 * @brief   the application functions of TRMOSC demo for the TOSHIBA
 *          'TMPM375' Device Series 
 * @version 0.0.0.1
 * @date    2014/09/29
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "stdint.h"
#include "tmpm375_tmrb.h"

/* Private define ------------------------------------------------------------*/
#define TMRB7COUNT	(0x0000FFFFUL)

/**
  * @brief  initialize TMBR7
  * @param  None
  * @retval None
  */
void InitTMRB7(void)
{
	TMRB_InitTypeDef m_tmrb;

	m_tmrb.Mode = TMRB_INTERVAL_TIMER;
	m_tmrb.ClkDiv = TMRB_CLK_DIV_2;
	m_tmrb.TrailingTiming = TMRB7COUNT;
	m_tmrb.UpCntCtrl = TMRB_FREE_RUN;
	m_tmrb.LeadingTiming = TMRB7COUNT;

	TMRB_Enable(TSB_TB7);
	TMRB_Init(TSB_TB7, &m_tmrb);
	TMRB_SetCaptureTiming(TSB_TB7, TMRB_CAPTURE_IN_RISING);
	TMRB_SetExtStartTrg(TSB_TB7, ENABLE, TMRB_TRG_EDGE_FALLING);
	TMRB_SetRunState(TSB_TB7, TMRB_STOP);
}

/**
  * @brief  Start Capture
  * @param  None
  * @retval None
  */
void StartCapture(void)
{
	TMRB_SetRunState(TSB_TB7, TMRB_STOP);
	NVIC_ClearPendingIRQ(INTCAP70_IRQn);
	TMRB_SetRunState(TSB_TB7, TMRB_RUN);
}

/**
  * @brief  Get Capture Data
  * @param  None
  * @retval Capture Data
  */
uint32_t GetCaptureData(void)
{
	uint32_t retval;

	for(;;){
		if (NVIC_GetPendingIRQ(INTCAP70_IRQn)) {
			retval = (uint32_t)TMRB_GetCaptureValue(TSB_TB7, TMRB_CAPTURE_0);
			break;
		}
		else {
			/* do nothing */
		}
	}
	NVIC_ClearPendingIRQ(INTCAP70_IRQn);

	return(retval);
}

/**
  * @brief  Stop Capture
  * @param  None
  * @retval None
  */
void StopCapture(void)
{
	TMRB_SetRunState(TSB_TB7, TMRB_STOP);
	NVIC_ClearPendingIRQ(INTCAP70_IRQn);
}
